@@ -279,9 +279,10 @@ def InitMeasurement():
     GenerateGraphBitmap(RecordWindow)
 #    RecordWindow.UpdateScreen()
     
+    RecordWindow.ui.lblStatus.hide()
     RecordWindow.ui.CanvasWidget.show()
     RecordWindow.UpdateScreen()
-    
+    app.processEvents() #force ui update   
     
 
     if(data.debug==1): 
@@ -342,6 +343,7 @@ def StopMeasurement():
     RecordWindow.UpdateScreenStop()
     RecordWindow.Canvas.update()
     RecordWindow.UpdateScreen()
+    app.processEvents() #force ui update   
     
 #    DeleteAlarm() #delete Alarm if existing
     
@@ -625,15 +627,16 @@ class frmRecordWindow(QMainWindow):
         self.ui = Ui_RecordWindow()
         self.ui.setupUi(self)
         
+        
+        app.processEvents() #force ui update   
+        
 #        scroller = self.ui.ScrollArea.property("kineticScroller").toPyObject()
 #        scroller.setEnabled(True)
         
         self.Canvas = MyGraphCanvas(self.ui.CanvasWidget)
         
         self.ui.CanvasWidget.setMinimumSize(QtCore.QSize(1000, data.GraphBitMapHeight)) #needed?
-        
-        
-        
+
         
         QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), self.StopMeasurement)
         QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
@@ -660,6 +663,7 @@ class frmRecordWindow(QMainWindow):
             self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
             
             
+        app.processEvents() #force ui update   
             
             
 
@@ -1821,8 +1825,9 @@ class DisplayStatusDaemon:
         if(tmp[1]=="off"): data.DisplayIsOn=False
         elif(tmp[1]=="on"): 
             data.DisplayIsOn=True
-            if(data.run==True): 
-                if(data.debug==1): print "Update screen & graph"
+#            if(data.run==True): 
+            if(RecordWindow.isHidden()==False): 
+                if(data.debug==1): print "Update RecordWindow screen & graph"
 #                data.ChangesInGraph=True
 
                 GenerateStatisticData()   
